@@ -20,7 +20,7 @@
 
 package App::MtAws::QueueEngine;
 
-our $VERSION = '1.051_1';
+our $VERSION = '1.051_2';
 
 use strict;
 use warnings;
@@ -31,38 +31,80 @@ use App::MtAws::QueueJobResult;
 sub new
 {
 	my ($class, %args) = @_;
-	my $self = \%args;
-	$self->{children}||confess;
-	$self->{task_inc} = 0;
-	@{$self->{freeworkers}} = keys %{$self->{children}};
+	my $self = {};
 	bless $self, $class;
+	$self->{task_inc} = 0;
+	$self->{tasks} = undef;
+	$self->{freeworkers} = undef;
+	$self->{workers} = {};
+	$self->init(%args);
 	return $self;
 }
 
+sub init { confess "Unimplemented" }
+sub queue { confess "Unimplemented" }
+
+sub add_worker
+{
+	my ($self, $worker_id) = @_;
+	$self->{workers}{$worker_id} = {};
+}
+
+sub unqueue_task
+{
+	my ($self, $worker_id) = @_;
+	my $task_id = delete $self->{workers}{$worker_id}{task};
+	my $task = delete $self->{tasks}{$task_id} or confess;
+	push @{ $self->{freeworkers} }, $worker_id;
+	return $task;
+}
+
+sub _next_task_id
+{
+	my ($self) = @_;
+	my $next_id = ++$self->{task_inc};
+	$next_id > 0 or confess;
+	$next_id;
+}
 
 sub process
 {
-	my ($self, $task) = @_;
-	my $tasks = {};
+	my ($self, $job) = @_;
+	confess "code is not reentrant" if defined $self->{tasks};
+	$self->{tasks} = {};
+	@{$self->{freeworkers}} = keys %{$self->{workers}};
 	while () {
 		if (@{ $self->{freeworkers} }) {
-			my $res = $task->next;
+			my $res = $job->next;
 			if ($res->{code} eq JOB_OK) {
-				my $task_id = ++$self->{task_inc};
+				my $task_id = $self->_next_task_id;
+
 				my $worker_id = shift @{ $self->{freeworkers} };
-				$tasks->{$task_id} = $res->{task};
-				$self->queue($worker_id, $task_id, $task);
+				my $task = $res->{task};
+
+				$task->{_id} = $task_id;
+				$self->queue($worker_id, $task);
+
+				$self->{tasks}{$task_id} = $task;
+				$self->{workers}{$worker_id}{task} = $task_id;
+
 			} elsif ($res->{code} eq JOB_WAIT) {
-				$self->wait_worker($tasks);
+				$self->wait_worker();
 			} elsif ($res->{code} eq JOB_DONE) {
-				return $task
+				return $job
 			} else {
 				confess;
 			}
 		} else {
-			$self->wait_worker($tasks);
+			$self->wait_worker();
 		}
 	}
 }
 
+sub get_busy_workers_ids
+{
+	my ($self) = @_;
+	grep { $self->{workers}{$_}{task} } keys %{ $self->{workers}};
+}
+
 1;
