@@ -26,35 +26,28 @@ use LCGRandom;
 use base q{App::MtAws::QueueEngine};
 use Carp;
 
-sub new
+sub init
 {
-	my ($class, $n) = @_;
-	my $self = $class->SUPER::new(children => {map { $_ => {} } (1..$n) });
-	$self;
+	my ($self, %args) = @_;
+	$self->add_worker($_) for (1..$args{n});
 }
 
-sub queue
-{
-	my ($self, $worker_id, $task_id, $task) = @_;
-	$self->{children}{$worker_id}{task} = $task_id;
-}
+sub queue { }
 
 sub wait_worker
 {
-	my ($self, $tasks) = @_;
-	my @possible = grep { $self->{children}{$_}{task} } keys %{ $self->{children}};
-
+	my ($self) = @_;
+	my @possible = $self->get_busy_workers_ids;
 	confess unless @possible;
-	my $rr = lcg_irand(0, @possible-1);
-	my $r = $possible[$rr];
-	my $t_id = delete $self->{children}{$r}{task};
-	my $t = delete $tasks->{$t_id} or confess;
-	push @{ $self->{freeworkers} }, $r;
-	my $method = "on_$t->{action}";
+	my $worker_id = $possible[lcg_irand(0, @possible-1)];
+
+	my $task = $self->unqueue_task($worker_id);
+
+	my $method = "on_$task->{action}";
 	no strict 'refs';
 
-	my @r = $self->$method(%{$t->{args}});
-	$t->{cb_task_proxy}->(@r);
+	my @r = $self->$method(%{$task->{args}});
+	$task->{cb_task_proxy}->(@r);
 }
 
 
